RelayOptions class

Dedupe options for CurlRelay.

Constructors

RelayOptions({Duration dedupeTtl = const Duration(minutes: 1), int dedupeMaxEntries = 10000})
const

Properties

dedupeMaxEntries → int
final
dedupeTtl → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited